"""This is the “nester.py" module, and it provides one function called
print_lol() which prints lists that may or may not include nested lists."""

def print_lol(the_list,level):
    for each_item in the_list:
        if isinstance(each_item, list):
            print_lol(each_item,level+1)
        else:
            for tab_stop in range(level):
                print("\t", end = '')
            print(each_item)



from distutils.core import setup
setup(
    name = 'nestersows',
    version = '1.2.0',
    py_modules = ['nestersows'],
    author = 'jaytj005',
    author_email = 'jaytj005@yahoo.com',
    url = 'https://www.w3schools.com',
    description = 'A simple printer of nested lists'

    )
